@@ -141,7 +141,8 @@ class ProtMotionCorr(ProtAlignMovies):
                       label='Compute micrograph thumbnail?',
                       help='When using this option, we will compute a '
                            'micrograph thumbnail and keep it with the '
-                           'micrograph object for visualization purposes. ')
+                           'micrograph object for visualization purposes.\n\n'
+                           '*IMPORTANT: this requires EMAN2 plugin and binaries.*')
 
         form.addParam('extraProtocolParams', params.StringParam, default='',
                       expertLevel=cons.LEVEL_ADVANCED,
